@@ -180,7 +180,7 @@ def copy_meta_data(src_path,dst_path):
     dst_data['meta_data']['XMP:Subject'] = src_data['meta_data']['XMP:Subject']
     f.image.save_file_obj(dst_data)
 
-def to_jpg(src_path,**kwargs):
+def to_jpg(src_path,dst_path=None,**kwargs):
     '''
         Convert an image or list of images to jpg.
 
@@ -216,7 +216,8 @@ def to_jpg(src_path,**kwargs):
     for path in src_list:
         if f.exists(path) is False:
             print(f"Could not find: {path}")
-        output_path = _convert_image(path, "jpg")
+            
+        output_path = _convert_image(path, "jpg",dst_path)
         if f.exists(output_path):
             outputs.append(output_path)
             if delete_original_after is True:
@@ -322,7 +323,7 @@ def has_transparency(img):
 
     return False
 
-def _convert_image(src_path,output_ext):
+def _convert_image(src_path,output_ext,dst_path=None):
     oext = f.get_ext(src_path)
     extension = csu.format.extension(output_ext)
 
@@ -333,8 +334,9 @@ def _convert_image(src_path,output_ext):
         print(f"Could not find: {src_path}")
         return False
     else:
-        output_path = f"{os.path.dirname(src_path)}/{f.get_name_no_ext(src_path)}.{extension}"
-        print(f"output_path: {output_path}")
+        if dst_path is None:
+            dst_path = f"{os.path.dirname(src_path)}/{f.get_name_no_ext(src_path)}.{extension}"
+        # print(f"output_path: {output_path}")
         try:
             im = Image.open(src_path)
             convert_to = 'RGB'
@@ -344,8 +346,8 @@ def _convert_image(src_path,output_ext):
                 extension ="jpeg"
                 convert_to = "RGB"
             im = im.convert(convert_to)
-            im.save(output_path,extension)
-            return output_path
+            im.save(dst_path,extension)
+            return dst_path
         except UnidentifiedImageError:
             print(f"Skipping file, could not convert: {src_path}.")
             return False
